@@ -3,12 +3,8 @@
 #' \emph{landscapetools} provides utility functions to work with landscape data
 #' (raster* Objects).
 #'
-
-# nocov start
-# nolint start
+#' @useDynLib landscapetools, .registration = TRUE
+#' @importFrom Rcpp sourceCpp
 "_PACKAGE"
 
-globalVariables(c("value", ".", "id"))
-
-# nolint end
-# nocov end
+globalVariables(c("value", ".", "id", "y", "z"))
